<a id="mypy-boto3-iotsitewise"></a>

# mypy-boto3-iotsitewise

[![PyPI - types-aiobotocore-iotsitewise](https://img.shields.io/pypi/v/types-aiobotocore-iotsitewise.svg?color=blue)](https://pypi.org/project/types-aiobotocore-iotsitewise)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-iotsitewise.svg?color=blue)](https://pypi.org/project/types-aiobotocore-iotsitewise)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-iotsitewise?color=blue)](https://pypistats.org/packages/types-aiobotocore-iotsitewise)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.IoTSiteWise 1.20.47](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise.html#IoTSiteWise)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.4.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[types-aiobotocore-iotsitewise docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_iotsitewise/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-iotsitewise](#mypy-boto3-iotsitewise)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `IoTSiteWise`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `IoTSiteWise` service.

```bash
# install with aiobotocore type annotations
python -m pip install 'types-aiobotocore[iotsitewise]'

# Lite version does not provide session.create_client overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'types-aiobotocore-lite[iotsitewise]'

# standalone installation
python -m pip install types-aiobotocore-iotsitewise
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[iotsitewise]` in your environment:
  `python -m pip install 'types-aiobotocore[iotsitewise]'`

Both type checking and auto-complete should work for `IoTSiteWise` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `types-aiobotocore[iotsitewise]` in your environment:
  `python -m pip install 'types-aiobotocore[iotsitewise]'`

Both type checking and auto-complete should work for `IoTSiteWise` service. No
explicit type annotations required, write your `aiobotocore` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`types-aiobotocore` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[iotsitewise]` in your environment:
  `python -m pip install 'types-aiobotocore[iotsitewise]'`
- Run `mypy` as usual

Type checking should work for `IoTSiteWise` service. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `types-aiobotocore[iotsitewise]` in your environment:
  `python -m pip install 'types-aiobotocore[iotsitewise]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `IoTSiteWise` service. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`IoTSiteWiseClient` provides annotations for
`session.create_client("iotsitewise")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_iotsitewise import IoTSiteWiseClient

session = get_session()
async with session.create_client("iotsitewise") as client:
    client: IoTSiteWiseClient
    # now client usage is checked by mypy and IDE should provide code auto-complete
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_iotsitewise.paginator` module contains type annotations for
all paginators.

````python
from aiobotocore.session import get_session

from types_aiobotocore_iotsitewise import IoTSiteWiseClient
from types_aiobotocore_iotsitewise.paginator import (
    GetAssetPropertyAggregatesPaginator,
    GetAssetPropertyValueHistoryPaginator,
    GetInterpolatedAssetPropertyValuesPaginator,
    ListAccessPoliciesPaginator,
    ListAssetModelsPaginator,
    ListAssetRelationshipsPaginator,
    ListAssetsPaginator,
    ListAssociatedAssetsPaginator,
    ListDashboardsPaginator,
    ListGatewaysPaginator,
    ListPortalsPaginator,
    ListProjectAssetsPaginator,
    ListProjectsPaginator,
    ListTimeSeriesPaginator,
)

session = get_session()
async with session.create_client("iotsitewise") as client:
    client: IoTSiteWiseClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        get_asset_property_aggregates_paginator: GetAssetPropertyAggregatesPaginator = client.get_paginator("get_asset_property_aggregates")
        get_asset_property_value_history_paginator: GetAssetPropertyValueHistoryPaginator = client.get_paginator("get_asset_property_value_history")
        get_interpolated_asset_property_values_paginator: GetInterpolatedAssetPropertyValuesPaginator = client.get_paginator("get_interpolated_asset_property_values")
        list_access_policies_paginator: ListAccessPoliciesPaginator = client.get_paginator("list_access_policies")
        list_asset_models_paginator: ListAssetModelsPaginator = client.get_paginator("list_asset_models")
        list_asset_relationships_paginator: ListAssetRelationshipsPaginator = client.get_paginator("list_asset_relationships")
        list_assets_paginator: ListAssetsPaginator = client.get_paginator("list_assets")
        list_associated_assets_paginator: ListAssociatedAssetsPaginator = client.get_paginator("list_associated_assets")
        list_dashboards_paginator: ListDashboardsPaginator = client.get_paginator("list_dashboards")
        list_gateways_paginator: ListGatewaysPaginator = client.get_paginator("list_gateways")
        list_portals_paginator: ListPortalsPaginator = client.get_paginator("list_portals")
        list_project_assets_paginator: ListProjectAssetsPaginator = client.get_paginator("list_project_assets")
        list_projects_paginator: ListProjectsPaginator = client.get_paginator("list_projects")
        list_time_series_paginator: ListTimeSeriesPaginator = client.get_paginator("list_time_series")
    ```


### Waiters annotations

`types_aiobotocore_iotsitewise.waiter` module contains type annotations for all waiters.

```python
from aiobotocore.session import get_session

from types_aiobotocore_iotsitewise.client import IoTSiteWiseClient
from types_aiobotocore_iotsitewise.waiter import (
    AssetActiveWaiter,
    AssetModelActiveWaiter,
    AssetModelNotExistsWaiter,
    AssetNotExistsWaiter,
    PortalActiveWaiter,
    PortalNotExistsWaiter,
)

session = get_session()
async with session.create_client("iotsitewise") as client:
    client: IoTSiteWiseClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        asset_active_waiter: AssetActiveWaiter = client.get_waiter("asset_active")
        asset_model_active_waiter: AssetModelActiveWaiter = client.get_waiter("asset_model_active")
        asset_model_not_exists_waiter: AssetModelNotExistsWaiter = client.get_waiter("asset_model_not_exists")
        asset_not_exists_waiter: AssetNotExistsWaiter = client.get_waiter("asset_not_exists")
        portal_active_waiter: PortalActiveWaiter = client.get_waiter("portal_active")
        portal_not_exists_waiter: PortalNotExistsWaiter = client.get_waiter("portal_not_exists")
    ```





<a id="literals"></a>

### Literals

`types_aiobotocore_iotsitewise.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from types_aiobotocore_iotsitewise.literals import (
    AggregateTypeType,
    AssetActiveWaiterName,
    AssetErrorCodeType,
    AssetModelActiveWaiterName,
    AssetModelNotExistsWaiterName,
    AssetModelStateType,
    AssetNotExistsWaiterName,
    AssetRelationshipTypeType,
    AssetStateType,
    AuthModeType,
    BatchPutAssetPropertyValueErrorCodeType,
    CapabilitySyncStatusType,
    ComputeLocationType,
    ConfigurationStateType,
    DetailedErrorCodeType,
    DisassociatedDataStorageStateType,
    EncryptionTypeType,
    ErrorCodeType,
    ForwardingConfigStateType,
    GetAssetPropertyAggregatesPaginatorName,
    GetAssetPropertyValueHistoryPaginatorName,
    GetInterpolatedAssetPropertyValuesPaginatorName,
    IdentityTypeType,
    ImageFileTypeType,
    ListAccessPoliciesPaginatorName,
    ListAssetModelsPaginatorName,
    ListAssetRelationshipsPaginatorName,
    ListAssetsFilterType,
    ListAssetsPaginatorName,
    ListAssociatedAssetsPaginatorName,
    ListDashboardsPaginatorName,
    ListGatewaysPaginatorName,
    ListPortalsPaginatorName,
    ListProjectAssetsPaginatorName,
    ListProjectsPaginatorName,
    ListTimeSeriesPaginatorName,
    ListTimeSeriesTypeType,
    LoggingLevelType,
    MonitorErrorCodeType,
    PermissionType,
    PortalActiveWaiterName,
    PortalNotExistsWaiterName,
    PortalStateType,
    PropertyDataTypeType,
    PropertyNotificationStateType,
    QualityType,
    ResourceTypeType,
    StorageTypeType,
    TimeOrderingType,
    TraversalDirectionType,
    TraversalTypeType,
    ServiceName,
    PaginatorName,
    WaiterName,
)

def check_value(value: AggregateTypeType) -> bool:
    ...
````

<a id="typed-dictionaries"></a>

### Typed dictionaries

`types_aiobotocore_iotsitewise.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_iotsitewise.type_defs import (
    AccessPolicySummaryTypeDef,
    AggregatedValueTypeDef,
    AggregatesTypeDef,
    AlarmsTypeDef,
    AssetCompositeModelTypeDef,
    AssetErrorDetailsTypeDef,
    AssetHierarchyInfoTypeDef,
    AssetHierarchyTypeDef,
    AssetModelCompositeModelDefinitionTypeDef,
    AssetModelCompositeModelTypeDef,
    AssetModelHierarchyDefinitionTypeDef,
    AssetModelHierarchyTypeDef,
    AssetModelPropertyDefinitionTypeDef,
    AssetModelPropertyTypeDef,
    AssetModelStatusTypeDef,
    AssetModelSummaryTypeDef,
    AssetPropertyTypeDef,
    AssetPropertyValueTypeDef,
    AssetRelationshipSummaryTypeDef,
    AssetStatusTypeDef,
    AssetSummaryTypeDef,
    AssociateAssetsRequestRequestTypeDef,
    AssociateTimeSeriesToAssetPropertyRequestRequestTypeDef,
    AssociatedAssetsSummaryTypeDef,
    AttributeTypeDef,
    BatchAssociateProjectAssetsRequestRequestTypeDef,
    BatchAssociateProjectAssetsResponseTypeDef,
    BatchDisassociateProjectAssetsRequestRequestTypeDef,
    BatchDisassociateProjectAssetsResponseTypeDef,
    BatchPutAssetPropertyErrorEntryTypeDef,
    BatchPutAssetPropertyErrorTypeDef,
    BatchPutAssetPropertyValueRequestRequestTypeDef,
    BatchPutAssetPropertyValueResponseTypeDef,
    CompositeModelPropertyTypeDef,
    ConfigurationErrorDetailsTypeDef,
    ConfigurationStatusTypeDef,
    CreateAccessPolicyRequestRequestTypeDef,
    CreateAccessPolicyResponseTypeDef,
    CreateAssetModelRequestRequestTypeDef,
    CreateAssetModelResponseTypeDef,
    CreateAssetRequestRequestTypeDef,
    CreateAssetResponseTypeDef,
    CreateDashboardRequestRequestTypeDef,
    CreateDashboardResponseTypeDef,
    CreateGatewayRequestRequestTypeDef,
    CreateGatewayResponseTypeDef,
    CreatePortalRequestRequestTypeDef,
    CreatePortalResponseTypeDef,
    CreateProjectRequestRequestTypeDef,
    CreateProjectResponseTypeDef,
    CustomerManagedS3StorageTypeDef,
    DashboardSummaryTypeDef,
    DeleteAccessPolicyRequestRequestTypeDef,
    DeleteAssetModelRequestRequestTypeDef,
    DeleteAssetModelResponseTypeDef,
    DeleteAssetRequestRequestTypeDef,
    DeleteAssetResponseTypeDef,
    DeleteDashboardRequestRequestTypeDef,
    DeleteGatewayRequestRequestTypeDef,
    DeletePortalRequestRequestTypeDef,
    DeletePortalResponseTypeDef,
    DeleteProjectRequestRequestTypeDef,
    DeleteTimeSeriesRequestRequestTypeDef,
    DescribeAccessPolicyRequestRequestTypeDef,
    DescribeAccessPolicyResponseTypeDef,
    DescribeAssetModelRequestRequestTypeDef,
    DescribeAssetModelResponseTypeDef,
    DescribeAssetPropertyRequestRequestTypeDef,
    DescribeAssetPropertyResponseTypeDef,
    DescribeAssetRequestRequestTypeDef,
    DescribeAssetResponseTypeDef,
    DescribeDashboardRequestRequestTypeDef,
    DescribeDashboardResponseTypeDef,
    DescribeDefaultEncryptionConfigurationResponseTypeDef,
    DescribeGatewayCapabilityConfigurationRequestRequestTypeDef,
    DescribeGatewayCapabilityConfigurationResponseTypeDef,
    DescribeGatewayRequestRequestTypeDef,
    DescribeGatewayResponseTypeDef,
    DescribeLoggingOptionsResponseTypeDef,
    DescribePortalRequestRequestTypeDef,
    DescribePortalResponseTypeDef,
    DescribeProjectRequestRequestTypeDef,
    DescribeProjectResponseTypeDef,
    DescribeStorageConfigurationResponseTypeDef,
    DescribeTimeSeriesRequestRequestTypeDef,
    DescribeTimeSeriesResponseTypeDef,
    DetailedErrorTypeDef,
    DisassociateAssetsRequestRequestTypeDef,
    DisassociateTimeSeriesFromAssetPropertyRequestRequestTypeDef,
    ErrorDetailsTypeDef,
    ExpressionVariableTypeDef,
    ForwardingConfigTypeDef,
    GatewayCapabilitySummaryTypeDef,
    GatewayPlatformTypeDef,
    GatewaySummaryTypeDef,
    GetAssetPropertyAggregatesRequestRequestTypeDef,
    GetAssetPropertyAggregatesResponseTypeDef,
    GetAssetPropertyValueHistoryRequestRequestTypeDef,
    GetAssetPropertyValueHistoryResponseTypeDef,
    GetAssetPropertyValueRequestRequestTypeDef,
    GetAssetPropertyValueResponseTypeDef,
    GetInterpolatedAssetPropertyValuesRequestRequestTypeDef,
    GetInterpolatedAssetPropertyValuesResponseTypeDef,
    GreengrassTypeDef,
    GreengrassV2TypeDef,
    GroupIdentityTypeDef,
    IAMRoleIdentityTypeDef,
    IAMUserIdentityTypeDef,
    IdentityTypeDef,
    ImageFileTypeDef,
    ImageLocationTypeDef,
    ImageTypeDef,
    InterpolatedAssetPropertyValueTypeDef,
    ListAccessPoliciesRequestRequestTypeDef,
    ListAccessPoliciesResponseTypeDef,
    ListAssetModelsRequestRequestTypeDef,
    ListAssetModelsResponseTypeDef,
    ListAssetRelationshipsRequestRequestTypeDef,
    ListAssetRelationshipsResponseTypeDef,
    ListAssetsRequestRequestTypeDef,
    ListAssetsResponseTypeDef,
    ListAssociatedAssetsRequestRequestTypeDef,
    ListAssociatedAssetsResponseTypeDef,
    ListDashboardsRequestRequestTypeDef,
    ListDashboardsResponseTypeDef,
    ListGatewaysRequestRequestTypeDef,
    ListGatewaysResponseTypeDef,
    ListPortalsRequestRequestTypeDef,
    ListPortalsResponseTypeDef,
    ListProjectAssetsRequestRequestTypeDef,
    ListProjectAssetsResponseTypeDef,
    ListProjectsRequestRequestTypeDef,
    ListProjectsResponseTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    ListTimeSeriesRequestRequestTypeDef,
    ListTimeSeriesResponseTypeDef,
    LoggingOptionsTypeDef,
    MeasurementProcessingConfigTypeDef,
    MeasurementTypeDef,
    MetricProcessingConfigTypeDef,
    MetricTypeDef,
    MetricWindowTypeDef,
    MonitorErrorDetailsTypeDef,
    MultiLayerStorageTypeDef,
    PaginatorConfigTypeDef,
    PortalResourceTypeDef,
    PortalStatusTypeDef,
    PortalSummaryTypeDef,
    ProjectResourceTypeDef,
    ProjectSummaryTypeDef,
    PropertyNotificationTypeDef,
    PropertyTypeDef,
    PropertyTypeTypeDef,
    PutAssetPropertyValueEntryTypeDef,
    PutDefaultEncryptionConfigurationRequestRequestTypeDef,
    PutDefaultEncryptionConfigurationResponseTypeDef,
    PutLoggingOptionsRequestRequestTypeDef,
    PutStorageConfigurationRequestRequestTypeDef,
    PutStorageConfigurationResponseTypeDef,
    ResourceTypeDef,
    ResponseMetadataTypeDef,
    RetentionPeriodTypeDef,
    TagResourceRequestRequestTypeDef,
    TimeInNanosTypeDef,
    TimeSeriesSummaryTypeDef,
    TransformProcessingConfigTypeDef,
    TransformTypeDef,
    TumblingWindowTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateAccessPolicyRequestRequestTypeDef,
    UpdateAssetModelRequestRequestTypeDef,
    UpdateAssetModelResponseTypeDef,
    UpdateAssetPropertyRequestRequestTypeDef,
    UpdateAssetRequestRequestTypeDef,
    UpdateAssetResponseTypeDef,
    UpdateDashboardRequestRequestTypeDef,
    UpdateGatewayCapabilityConfigurationRequestRequestTypeDef,
    UpdateGatewayCapabilityConfigurationResponseTypeDef,
    UpdateGatewayRequestRequestTypeDef,
    UpdatePortalRequestRequestTypeDef,
    UpdatePortalResponseTypeDef,
    UpdateProjectRequestRequestTypeDef,
    UserIdentityTypeDef,
    VariableValueTypeDef,
    VariantTypeDef,
    WaiterConfigTypeDef,
)

def get_structure() -> AccessPolicySummaryTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`types-aiobotocore-iotsitewise` version is the same as related `boto3` version
and follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[types-aiobotocore-iotsitewise docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_iotsitewise/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
